@@ -21,16 +21,15 @@ You should have received a copy of the GNU General Public License
 along with ProtonVPN.  If not, see <https://www.gnu.org/licenses/>.
 """
 from concurrent.futures import Future
-from pathlib import Path
 
 from gi.repository import GLib, GObject
 
 from proton.vpn import logging
 
 from proton.vpn.app.gtk import Gtk
-from proton.vpn.app.gtk.assets import icons
 from proton.vpn.app.gtk.controller import Controller
 from proton.vpn.app.gtk.widgets.login.logo import ProtonVPNLogo
+from proton.vpn.app.gtk.widgets.login.password_entry import PasswordEntry
 from proton.vpn.app.gtk.widgets.main.notifications import Notifications
 from proton.vpn.app.gtk.widgets.main.loading_widget import OverlayWidget, DefaultLoadingWidget
 
@@ -211,68 +210,6 @@ class LoginForm(Gtk.Box):  # pylint: disable=R0902
         self._password_entry.emit("activate")
 
 
-class PasswordEntry(Gtk.Entry):
-    """
-    Entry used to introduce the password in the login form.
-
-    On top of the inherited functionality from Gtk.Entry, an icon is shown
-    inside the text entry to show or hide the password.
-
-    By default, the text (password) introduced in the entry is not show.
-    Therefore, the icon to be able to show the text is displayed. Once this
-    icon is pressed, the text is revealed and the icon to hide the password
-    is shown instead.
-    """
-    def __init__(self):
-        super().__init__()
-        self.set_input_purpose(Gtk.InputPurpose.PASSWORD)
-        self.set_visibility(False)
-        # Load icon to hide the password.
-        eye_dirpath = Path("eye")
-        hide_fp = eye_dirpath / "hide.svg"
-        self._hide_pixbuff = icons.get(
-            hide_fp,
-            width=18,
-            height=18,
-            preserve_aspect_ratio=True
-        )
-        # Load icon to show the password.
-        show_fp = eye_dirpath / "show.svg"
-        self._show_pixbuff = icons.get(
-            show_fp,
-            width=18,
-            height=18,
-            preserve_aspect_ratio=True
-        )
-        # By default, the password is not shown. Therefore, the icon to
-        # be able to show the password is shown.
-        self.set_icon_from_pixbuf(
-            Gtk.EntryIconPosition.SECONDARY,
-            self._show_pixbuff
-        )
-        self.set_icon_activatable(
-            Gtk.EntryIconPosition.SECONDARY,
-            True
-        )
-        self.connect(
-            "icon-press", self._on_change_password_visibility_icon_press
-        )
-
-    def _on_change_password_visibility_icon_press(
-            self, gtk_entry_object,
-            gtk_icon_object, gtk_event  # pylint: disable=W0613
-    ):
-        """Changes password visibility, updating accordingly the icon."""
-        is_text_visible = gtk_entry_object.get_visibility()
-        gtk_entry_object.set_visibility(not is_text_visible)
-        self.set_icon_from_pixbuf(
-            Gtk.EntryIconPosition.SECONDARY,
-            self._show_pixbuff
-            if is_text_visible
-            else self._hide_pixbuff
-        )
-
-
 class LoginLinks(Gtk.Box):
     """Links shown in the login widget."""
     def __init__(self):
